@@ -1393,6 +1393,9 @@ start_login(host, autologin, name)
 	char *ttyn;
 	char *tty;
 
+	/* remove undesirables from the environment */
+        scrub_env();
+
 	/*
 	 * -h : pass on name of host.
 	 *		WARNING:  -h is accepted by login if and only if
@@ -1828,3 +1831,26 @@ rmut()
 	(void) chown(line, 0, 0);
 }  /* end of rmut */
 #endif	/* CRAY */
+
+
+/*
+ * scrub_env()
+ *
+ * Remove a few things from the environment that
+ * don't need to be there.
+ */
+scrub_env()
+{
+      register char **cpp, **cpp2;
+
+      for (cpp2 = cpp = environ; *cpp; cpp++) {
+              if (strncmp(*cpp, "LD_", 3) &&
+                  strncmp(*cpp, "_RLD_", 5) &&
+                  strncmp(*cpp, "ELF_LD_", 7) &&
+                  strncmp(*cpp, "LIBPATH=", 8) &&
+                  strncmp(*cpp, "IFS=", 4))
+                      *cpp2++ = *cpp;
+      }
+      *cpp2 = 0;
+}
+
